Stan Math Library: stan/math/fwd/scal/fun/tgamma.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

tgamma.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_TGAMMA_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_TGAMMA_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <boost/math/special_functions/digamma.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 tgamma(const fvar<T>& x) {
16 using boost::math::digamma;
17 using boost::math::tgamma;
18 T u = tgamma(x.val_);
19 return fvar<T>(u, x.d_ * u * digamma(x.val_));
20 }
21 }
22 }
23 #endif
stan::math::tgamma
var tgamma(const stan::math::var &a)
Return the Gamma function applied to the specified variable (C99).
Definition: tgamma.hpp:65
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::tgamma
fvar< T > tgamma(const fvar< T > &x)
Definition: tgamma.hpp:15
stan::math::fvar
Definition: fvar.hpp:13
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.